#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-6DKANAEllbyBEaNhBHkbRy
key:                  regex-applicative-0.3.4-6DKANAEllbyBEaNhBHkbRy
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  a83608e29f3c9a5e2614a11f330a0d11
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative
hs-libraries:         HSregex-applicative-0.3.4-6DKANAEllbyBEaNhBHkbRy
depends:
    base-4.18.2.1 containers-0.6.7
    filtrable-0.1.6.0-K9WObQJZ6p37OvrxrMIrFM transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

